@@ -59,15 +59,15 @@ def enter_and_leave_function(func: Callable) -> Callable:
         try:
             result = func(*args, **kwargs)
             if isinstance(result, ExecResult):
-                if rs.exit_status_code == 0:
+                if result.exit_status_code == 0:
                     log.info(
                         f"[{func_def_file}: {func_def_line}]"
-                        f" finish run function {func.__name__}(), stdout is: {rs.stdout} "
+                        f" finish run function {func.__name__}(), stdout is: {result.stdout} "
                     )
                 else:
                     log.error(
                         f"[{func_def_file}: {func_def_line}]"
-                        f" failed to run function {func.__name__}(), stderr is: {rs.stderr} "
+                        f" failed to run function {func.__name__}(), stderr is: {result.stderr} "
                     )
             else:
                 log.info(
